@@ -34,36 +34,23 @@ class EditTool:
         """
         Perform precise string replacements with automatic backup and read-first safety.
 
-        WHEN TO USE:
-        - Targeted changes: Bug fixes, variable updates, specific line modifications
-        - Code refactoring: Renaming functions/variables throughout file
-        - Use write_file instead for: Complete rewrites, new files, major changes
+        USAGE:
+        - Targeted changes: Bug fixes, variable updates, line modifications
+        - Code refactoring: Renaming throughout file (use replace_all=True)
+        - Use write_file for: Complete rewrites, new files, major changes
 
-        CRITICAL SUCCESS FACTORS:
+        CRITICAL REQUIREMENTS:
         - Must read file first to see exact formatting
         - Copy exact text including all whitespace (spaces, tabs, newlines)
         - Include enough context to make old_string unique
-        - Match exact capitalization and punctuation
 
-        STRING MATCHING:
-        - Exact match required: Even small differences cause failure
-        - Include surrounding context: "def function_name(param):" not just "function_name"
-        - Preserve indentation: Copy spaces/tabs exactly as shown in file
-        - Multi-line: Include \n line breaks and proper indentation
-
-        REPLACE OPTIONS:
-        - replace_all=False: Changes first occurrence only
-        - replace_all=True: Changes all occurrences throughout file
-
-        BEST PRACTICES:
-        - Always read file first to understand structure and formatting
-        - Copy old_string exactly from read output
-        - Verify changes by reading modified section after edit
+        EXAMPLES:
+        edit_file('main.py', 'def old_name():', 'def new_name():')  # Single change
+        edit_file('config.py', 'DEBUG = True', 'DEBUG = False', replace_all=True)  # All occurrences
 
         COMMON ERRORS:
         - "String not found": old_string doesn't match exactly (check whitespace)
         - "Must read file first": Required for safety
-        - "Multiple matches": Be more specific with context
 
         Args:
             file_path: Path to file to edit
