@@ -62,37 +62,24 @@ class ReadTool:
         """
         Read file content with smart token management and flexible reading modes.
 
-        USAGE MODES:
-        - Full read (no args): Small-medium files, initial exploration
-        - Line ranges (LineArgs): Specific sections, around error locations
-        - Regex search (RegexArgs): Find patterns, function definitions
+        USAGE:
+        - Full read: Small-medium files, initial exploration
+        - Line ranges: Specific sections, error locations (LineArgs)
+        - Regex search: Find patterns, function definitions (RegexArgs)
 
-        WHEN TO USE:
-        - Always read before editing files for safety and context
-        - Code exploration and understanding structure
-        - Debugging specific sections or error locations
-        - Gathering context for modifications
+        EXAMPLES:
+        read_file('src/main.py')  # Full file read
+        read_file('config.json', LineArgs(lines_start=10, lines_end=20))  # Line range
+        read_file('*.py', RegexArgs(regex=r'def main'))  # Regex search
 
-        LIMITATIONS:
+        LIMITATIONS & ERRORS:
         - Large files (>50MB): Use line ranges to avoid token limits
-        - Binary files: Will fail with encoding errors
-        - Very long files: Content may be truncated with warning
-
-        BEST PRACTICES:
-        - Use line ranges for large files when you know target location
-        - Use regex for pattern searching: r'def function_name'
-        - Check 'success' field before processing content
-        - Read around error lines (±10-20 lines for context)
-
-        COMMON ERRORS:
         - "File not found": Check path spelling and existence
-        - "Permission denied": File access restrictions
         - "Content truncated": File too large, use targeted reading
 
         Args:
-            file_path: Path to file to read
+            file_path: absolute Path to file to read
             read_args: Either LineArgs or RegexArgs for specific reading modes
-
         Returns:
             Dict with content, metadata, and clear feedback
         """
