@@ -40,40 +40,23 @@ class RunTool:
         Execute commands with 2-state management: IDLE (ready) or RUNNING (active process).
 
         USAGE:
-        - Non-interactive: Quick commands, builds, tests - auto-kills on timeout
-        - Interactive: Long tasks, user prompts - returns control choices on timeout
+        - Non-interactive: Quick commands, auto-kills on timeout
+        - Interactive: Long tasks needing input, returns control choices on timeout
+        - Control commands when RUNNING: '' (continue), 'C-c' (kill), '>>> input' (send input)
 
-        WHEN TO USE INTERACTIVE:
-        - Commands needing input: installations, prompts, debugging
-        - Long/uncertain duration: servers, monitoring, large builds
-        - When you need to see output before completion
-
-        CONTROL COMMANDS (when RUNNING):
-        - '' (empty): Continue waiting, get more output
-        - 'C-c': Kill the running process
-        - '>>> input': Send input to process (note the >>> prefix)
-        - New commands: Rejected until current process finishes
-
-        TIMEOUTS:
-        - Quick commands: 30-60s
-        - Builds/tests: 300-600s
-        - Interactive cycles: 60-120s
-
-        LIMITATIONS:
-        - Only one process at a time
-        - Exact string matching for control commands
-        - Platform-specific command behavior
+        EXAMPLES:
+        run_command('npm test', timeout=60, interactive=False)  # Normal command
+        run_command('C-c')  # Control: kill running process
+        run_command('>>> 5')  # Control: send 5 as input to the program
 
         COMMON ERRORS:
         - "Another command running": Use 'C-c' to kill or wait for completion
         - "Command timed out": Process killed after timeout in non-interactive mode
-        - "Permission denied": Need appropriate permissions for command
 
         Args:
             command: Command to execute or control command ('', 'C-c', '>>> input')
             timeout: Maximum execution time in seconds (default: 300)
             interactive: If True, wait for timeout and return control choices
-
         Returns:
             Dict with execution results and state information
         """
@@ -136,9 +119,18 @@ class RunTool:
             import select
             import sys
 
-            # On Windows, select doesn't work with pipes, so use a simple timeout approach
-            if sys.platform == "win32":
-                # Windows: just try to read with very short timeout
+            # Detect WSL environment
+            is_wsl = False
+            try:
+                with open('/proc/version', 'r') as f:
+                    if 'microsoft' in f.read().lower():
+                        is_wsl = True
+            except:
+                pass
+
+            # Platform-specific handling: Windows and WSL use threading, native Unix uses select
+            if sys.platform == "win32" or is_wsl:
+                # Windows/WSL: Use threading approach (works better with I/O translation layers)
                 try:
                     # Use a simple non-blocking read attempt
                     if process.stdout.readable():
@@ -159,7 +151,7 @@ class RunTool:
                         t = threading.Thread(target=read_line, args=(process.stdout, q))
                         t.daemon = True
                         t.start()
-                        t.join(0.01)  # 10ms timeout
+                        t.join(0.05)  # 50ms timeout for better input processing
 
                         try:
                             while True:
@@ -174,7 +166,7 @@ class RunTool:
                         t = threading.Thread(target=read_line, args=(process.stderr, q))
                         t.daemon = True
                         t.start()
-                        t.join(0.01)  # 10ms timeout
+                        t.join(0.05)  # 50ms timeout for better input processing
 
                         try:
                             while True:
@@ -187,8 +179,8 @@ class RunTool:
                 except:
                     pass
             else:
-                # Unix: use select for non-blocking read
-                ready, _, _ = select.select([process.stdout, process.stderr], [], [], 0.01)
+                # Native Unix: use select for non-blocking read
+                ready, _, _ = select.select([process.stdout, process.stderr], [], [], 0.05)
 
                 for pipe in ready:
                     try:
@@ -596,8 +588,8 @@ class RunTool:
             process.stdin.write(input_text + '\n')
             process.stdin.flush()
 
-            # Small delay to let input be processed
-            time.sleep(0.1)
+            # Longer delay to let input be processed (especially for interactive programs)
+            time.sleep(0.5)
 
             # Now wait for timeout and collect output using timeline approach
             return self._wait_and_collect_output(timeout)
